* ------------------------------------------------------------------------------
*
*                       THE ECONOMICS OF WOMEN'S RIGHTS  
*                  
* ------------------------------------------------------------------------------
*
* by Michèle Tertilt, Matthias Doepke, Anne Hannusch and Laura Montenbruck
*
* This version: 2022-11-28
*
* This file replicates all regression tables in the paper, the appendix, 
* and the online appendix.
*
* Inpute file : final_data.dta in subdirectory '../data/'
*
* Output files: Regression tables saved as .tex files in subdirectory 
*               '../output/tables/'
*
* Notes:
* - To run the code, please adjust line 35 and line 38.
* - Section B. generates Table 1
*              You may need to run ssc install matsave / ssc install listtex
* - Section C. generates Tables 3-6 (reduced output) and Appendix Tables A.3-A.6
* - Section D. generates Online Appendix Tables B.2-B.5
* - Section E. generates the results underlying Table 7 and Online Appendix 
*              Tables B.6-B.9
*
* ------------------------------------------------------------------------------

* Housekeeping
clear all
set more off

* Adjust path to base directory
global basedirectory  "../ReplicationPackage"

* For Windows, change to "\"
global SLASH "/"

* Relative paths to subdirectories
global data 	"${basedirectory}${SLASH}data"
global tables 	"${basedirectory}${SLASH}output${SLASH}tables${SLASH}"
global figures	"${basedirectory}${SLASH}output${SLASH}figures${SLASH}"

* Load data
use "${data}${SLASH}final_data.dta", clear


* ------------------------------------------------------------------------------
* A. Setting things up
* ------------------------------------------------------------------------------

xtset c_id year

* Outcomes
global outcomes     Economic Political Labor Body

* Explanatory variables
global economics	gdp_pc tfr flfp
global religion		i.majority_catholic i.majority_muslim i.majority_buddhist
global controls     independence 

* GDP and religion interactions
global gdp_religion ""
foreach r of global religion{
	global gdp_religion $gdp_religion c.gdp_pc##`r'
}

global table_vars_noreligion $economics 1.majority_catholic#c.gdp_pc 1.majority_muslim#c.gdp_pc 1.majority_buddhist#c.gdp_pc 
global table_vars $economics 1.majority_catholic 1.majority_muslim 1.majority_buddhist 1.majority_catholic#c.gdp_pc 1.majority_muslim#c.gdp_pc 1.majority_buddhist#c.gdp_pc 

* ------------------------------------------------------------------------------
* B. Descriptive statistics
*
*    - Table 1: Examples of Women's Rights by Income
* ------------------------------------------------------------------------------

preserve 

	keep if year == 2000

	local vars univ_stand_women wbl_signcontract wbl_obtainpassport wbl_workatnight wbl_workanyindustry wbl_domesticviolence
	
	matrix values = J(6, 3, .)

	forval x = 1/6 {
	** Establishing Locals
	loc v = word("`vars'",`x')

		sum `v'
		matrix values[`x',1]=round(r(mean)*100,0.1)
		sum `v' if incomegroup=="Low income"
		matrix values[`x',2]=round(r(mean)*100,0.1)
		sum `v' if incomegroup=="High income"
		matrix values[`x',3]=round(r(mean)*100,0.1)

	}

	matsave values, path(${data}) replace saving  
	use "${data}${SLASH}values.dta", clear

	gen name="...be elected" if _n==1
	replace name="...sign a contract in the same ways as a man" if _n==2 
	replace name="...obtain a passport in the same ways as a man" if _n==3
	replace name="...work night shift the same way as a man" if _n==4
	replace name="...work in an industrial job the same way as a man" if _n==5
	replace name="...legal protection against domestic violence" if _n==6
	drop _rowname
	
	listtex name c1 c2 c3 using "${tables}/table1.tex", rstyle(tabular) replace
	erase "${data}${SLASH}values.dta"
	
restore

* ------------------------------------------------------------------------------
* C. Baseline regressions
*
*    - Tables 3 - 6 (reduced output)
*    - Appendix Tables A.3 - A.6 (full output)
*    - Appendix Figure A.1
* ------------------------------------------------------------------------------


foreach out of global outcomes {

* C.1 Run regressions

	// Column (1)
		eststo `out'_gdp :			qui reg `out'_rights gdp_pc $controls , cluster(c_id)
	
	// Column (2) 
		eststo `out'_pooled :		qui reg `out'_rights $economics $controls , cluster(c_id)
	
	// Column (3)  
		eststo `out'_FE :	 		qui reg `out'_rights $economics $controls i.year i.c_id, robust
		
	// Column (4)
		eststo `out'_religion :		qui reg `out'_rights $economics $religion $controls i.year, cluster(c_id) 
		
	// Column (5)
		eststo `out'_econ_rel_base: qui reg `out'_rights $gdp_religion tfr flfp $controls i.year, cluster(c_id)
		
	// Column (6): Appendix Tables only
		eststo `out'_rel_only : 	qui reg `out'_rights $religion $controls i.year, cluster(c_id) 		
		
		
* C.2 Create Tables

	* Table 3 - Table 6
	
	* Prepare table output
	local gdp_6 "\multicolumn{6}{l}{\textbf{A. Economic Variables}} \\ `: variable label gdp_pc' "	
	local reli_6 "\hline \multicolumn{6}{l}{\textbf{B. Interactions with Religion}} \\ `: variable label majority_catholic' $\times$ GPD p.c. "	
	local table_vars_noreligion $economics 1.majority_catholic#c.gdp_pc 1.majority_muslim#c.gdp_pc 1.majority_buddhist#c.gdp_pc 
	
	esttab `out'_gdp `out'_pooled `out'_FE `out'_religion `out'_econ_rel_base ///
		using "${tables}RegressionTables_`out'Rights_JEEA.tex", replace ///
		star(* 0.10 ** 0.05 *** 0.01) ar2 label noomitted nobaselevels  not b(%8.2f) alignment(D{.}{.}{2,5}) ///
		keep($table_vars_noreligion) nonotes ///
		mgroups("Dependent Variable: `out' Rights Index", pattern(1 0 0 0 0 0) ///
		prefix(\multicolumn{@span}{c}{)suffix(}) span erepeat(\cmidrule(lr){@span})) ///
		stats(N r2_a, fmt(0 3) layout("\multicolumn{1}{c}{@}" "\multicolumn{1}{c}{@}") labels(`"Observations"' `"Adjusted \(R^{2}\)"')) ///
		indicate("\hline Time FEs = *year" "Country FEs = *c_id" "Religion FEs = 1.majority_muslim") nomtitles ///
		coeflabels(gdp_pc "`gdp_6'" 1.majority_catholic#c.gdp_pc "`reli_6'") ///
		order(gdp_pc tfr flfp *)	

	* Appendix Tables A.3 - A.6	
	
	* Prepare table output
	local gdp_7 "\multicolumn{7}{l}{\textbf{A. Economic Variables}} \\ `: variable label gdp_pc' "	
	local reli_7 "\hline \multicolumn{7}{l}{\textbf{B. Interactions with Religion}} \\ `: variable label majority_catholic' $\times$ GPD p.c. "		
	local table_vars $economics 1.majority_catholic 1.majority_muslim 1.majority_buddhist 1.majority_catholic#c.gdp_pc 1.majority_muslim#c.gdp_pc ///
	1.majority_buddhist#c.gdp_pc 
	
	esttab `out'_gdp `out'_pooled `out'_FE `out'_religion `out'_econ_rel_base `out'_rel_only ///
		using "${tables}RegressionTables_`out'Rights_long_JEEA.tex", replace ///
		star(* 0.10 ** 0.05 *** 0.01) se ar2 label noomitted nobaselevels not b(%8.2f) alignment(D{.}{.}{2,5}) ///
		keep($table_vars) nonotes ///
		mgroups("Dependent Variable: `out' Rights Index", pattern(1 0 0 0 0 0) ///
		prefix(\multicolumn{@span}{c}{)suffix(}) span erepeat(\cmidrule(lr){@span})) ///
		indicate("\hline Time FEs = *year" "Country FEs = *c_id") nomtitles ///
		coeflabels(gdp_pc "`gdp_7'" 1.majority_catholic#c.gdp_pc "`reli_7'") ///
		order(gdp_pc tfr flfp *)
	
	
	* Appendix Figure A.1 Graphing time FEs, based on (5); 
	   local coeflabel 1970.year = "1970" 1971.year = "1971" 1972.year = " " 1973.year = " " 1974.year = " " 1975.year = "1975" ///
				1976.year = " " 1977.year = " " 1978.year = " " 1979.year = " " 1980.year = "1980" ///
				1981.year = " " 1982.year = " " 1983.year = " " 1984.year = " " 1985.year = "1985" ///
				1986.year = " " 1987.year = " " 1988.year = " " 1989.year = " " 1990.year = "1990" ///
				1991.year = " " 1992.year = " " 1993.year = " " 1994.year = " " 1995.year = "1995" ///
				1996.year = " " 1997.year = " " 1998.year = " " 1999.year = " " 2000.year = "2000" ///
				2001.year = " " 2002.year = " " 2003.year = " " 2004.year = " " 2005.year = "2005" ///
				2006.year = " " 2007.year = " " 2008.year = " " 2009.year = " " 2010.year = "2010" ///
				2011.year = " " 2012.year = " " 2013.year = "2013" 2014.year = " " 2015.year = "2015" ///
				2016.year = " " 2017.year = " " 2018.year = " " 2019.year = " " 2020.year = "2020" ///
				2021.year = " " 2022.year = " "

		coefplot `out'_econ_rel_base, keep(*year) coeflabels(`coeflabel', angle(45) labsize(*0.75)) vertical yline(0) ///
		ylab(,labsize(*0.75)) ///
		msize(small) title("`out' Rights", size(small)) name(`out'_timeFEs, replace)		
		
		graph export "${figures}${SLASH}`out'_timeFEs.pdf", as(pdf) replace	
	
}

		graph combine Economic_timeFEs Political_timeFEs Labor_timeFEs Body_timeFEs 
		graph export "${figures}${SLASH}AllRights_timeFEs_JEEA.pdf", as(pdf) replace			
		rm "${figures}${SLASH}Economic_timeFEs.pdf" 
		rm "${figures}${SLASH}Political_timeFEs.pdf" 
		rm "${figures}${SLASH}Labor_timeFEs.pdf" 
		rm "${figures}${SLASH}Body_timeFEs.pdf" 
		
* ------------------------------------------------------------------------------
* D. Robustness Checks
*
* 	- Online Appendix Tables B.2 - B.5
* ------------------------------------------------------------------------------

* Create indicator for common sample across rights indices
local outcomes Political_rights Labor_rights Economic_rights Body_rights
qui egen missings_int	= rowmiss(`outcomes' $economics majority_catholic majority_muslim majority_buddhist)


foreach out of global outcomes {

* D.1 Run regressions	
	
	// Column (1)
		eststo `out'_econ_rel_base: 	qui reg `out'_rights $gdp_religion tfr flfp $controls i.year, cluster(c_id)	
	
	// Column (2)
		eststo `out'_econ_rel_base_s: 	qui reg `out'_rights $gdp_religion tfr flfp $controls i.year if missings_int==0, cluster(c_id) 	

	// Column (3)
		eststo `out'_OPEC : 			qui reg `out'_rights $gdp_religion tfr flfp opec $controls i.year, cluster(c_id) 

	// Column (4)
		eststo `out'_no_timeFEs :		qui reg `out'_rights $gdp_religion tfr flfp $controls, cluster(c_id)
	
	// Column (5)
		eststo `out'_school_rel :		qui reg `out'_rights $gdp_religion sec_school_enroll flfp $controls i.year, cluster(c_id) 
		estadd local country "No"
	
* D.2 Create Tables

	* Prepare table output
	local gdp_6 "\multicolumn{6}{l}{\textbf{A. Economic Variables}} \\ `: variable label gdp_pc' "	
	local religion_6 "\hline \multicolumn{6}{l}{\textbf{B. Religion and Interactions with Religion}} \\ `: variable label majority_catholic'"
	local table_vars $economics 1.majority_catholic 1.majority_muslim 1.majority_buddhist 1.majority_catholic#c.gdp_pc 1.majority_muslim#c.gdp_pc ///
	1.majority_buddhist#c.gdp_pc 
	
	esttab `out'_econ_rel_base `out'_econ_rel_base_s `out'_OPEC `out'_no_timeFEs `out'_school_rel ///
		using "${tables}RegressionTables_`out'Rights_robustness_JEEA.tex", replace not b(%8.2f) alignment(D{.}{.}{2,5}) ///
		star(* 0.10 ** 0.05 *** 0.01) se ar2 label noomitted nobaselevels nomtitles ///
		keep($table_vars opec sec_school_enroll) nonotes ///
		mgroups("Dependent Variable: `out' Rights Index", pattern(1 0 0 0) ///
		prefix(\multicolumn{@span}{c}{)suffix(}) span erepeat(\cmidrule(lr){@span})) ///
		coeflabels(gdp_pc "`gdp_6'" 1.majority_catholic "`religion_6'") ///
		order(gdp_pc tfr flfp opec sec_school_enroll *)
		
	
}

* ------------------------------------------------------------------------------
* E. Additional Factors
*
* 	- Table 7 (summary)
* 	- Online Appendix Tables B.6 - B.9
* ------------------------------------------------------------------------------


foreach out of global outcomes {

* E.1 Run regressions	
	
	// Column (1)
		eststo `out'_econ_rel_base: 	qui reg `out'_rights $gdp_religion tfr flfp $controls i.year, cluster(c_id)	
	
	// Column (2)
		eststo `out'_femshare_rel: 		qui reg `out'_rights $gdp_religion tfr flfp fem_pop_share $controls i.year, cluster(c_id) 
		estadd local country "No"
		
	// Column (3)
		eststo `out'_sector_rel:		qui reg `out'_rights $gdp_religion tfr flfp agriculture_emp $controls i.year, cluster(c_id) 
		estadd local country "No"
		
	// Column (4) 
		eststo `out'_gov_eff_rel:		qui reg `out'_rights $gdp_religion tfr flfp goveff $controls i.year, cluster(c_id) 
		estadd local country "No"
		
	// Column (5)
		eststo `out'_wmingo_org_rel:	qui reg `out'_rights $gdp_religion tfr flfp women_ingo $controls i.year, cluster(c_id) 
		estadd local country "No"
	
	// Column (6)
		eststo `out'_contot_org_rel:	qui reg `out'_rights $gdp_religion tfr flfp conventions $controls i.year, cluster(c_id) 
		estadd local country "No"
	
	// Column (7)
		eststo `out'_rat_rel: 			qui reg `out'_rights $gdp_religion  tfr flfp ratifications_regional $controls i.year, cluster(c_id)
		estadd local country "No"
	
	// Column (8)
		eststo `out'_WiP_rel: 			qui reg `out'_rights $gdp_religion  tfr flfp parliament_p20_comb $controls i.year, cluster(c_id)
		estadd local country "No"

		
* E.2 Create Tables

	* Prepare table output
	local gdp_8 "\multicolumn{8}{l}{\textbf{A. Economic Variables}} \\ `: variable label gdp_pc' "	
	local fem_8 "\hline \multicolumn{8}{l}{\textbf{B. Additional Factors}} \\ `: variable label fem_pop_share' "

	esttab `out'_econ_rel_base `out'_femshare_rel `out'_sector_rel `out'_gov_eff_rel `out'_wmingo_org_rel `out'_contot_org_rel `out'_rat_rel `out'_WiP_rel ///
		using "${tables}RegressionTables_`out'Rights_additional_factors_JEEA.tex", replace ///
		star(* 0.10 ** 0.05 *** 0.01) se ar2 label noomitted nobaselevels nomtitles not b(%8.2f) alignment(D{.}{.}{2,5}) ///
		keep($table_vars_noreligion fem_pop_share  agriculture_emp goveff women_ingo conventions ratifications_regional parliament_p20_comb) nonotes ///
		mgroups("Dependent Variable: `out' Rights Index", pattern(1 0 0 0 0 0 0 0 0) ///
		prefix(\multicolumn{@span}{c}{)suffix(}) span erepeat(\cmidrule(lr){@span})) ///
		indicate("\hline Time FEs = *year" "Religion FEs = 1.majority_muslim") ///
		scalars("country Country FEs") ///
		coeflabels(gdp_pc "`gdp_8'" fem_pop_share "`fem_8'") 		

}

* ------------------------------------------------------------------------------
*								end of do-file
* ------------------------------------------------------------------------------
